notetools.NaturalHarmonic
=========================

.. abjad-lineage:: abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic

.. autoclass:: abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.add_artificial_harmonic
      ~abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.lilypond_duration_multiplier
      ~abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.lilypond_format
      ~abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.note_head
      ~abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.override
      ~abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.select
      ~abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.set
      ~abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.sounding_pitch
      ~abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.storage_format
      ~abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.suono_reale
      ~abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.written_duration
      ~abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.written_pitch
      ~abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.written_pitch_indication_is_at_sounding_pitch
      ~abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.written_pitch_indication_is_nonsemantic
      ~abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.__copy__
      ~abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.__eq__
      ~abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.__mul__
      ~abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.__ne__
      ~abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.__repr__
      ~abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.__rmul__
      ~abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.__str__

Bases
-----

- :py:class:`notetools.Note <abjad.tools.notetools.Note.Note.Note>`

- :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

- :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

- :py:class:`notetools.Harmonic <abjad.tools.notetools.Harmonic.Harmonic.Harmonic>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.override
   :noindex:

.. autoattribute:: abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.set
   :noindex:

.. autoattribute:: abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.storage_format
   :noindex:

.. autoattribute:: abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.suono_reale
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.lilypond_duration_multiplier
   :noindex:

.. autoattribute:: abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.note_head
   :noindex:

.. autoattribute:: abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.sounding_pitch
   :noindex:

.. autoattribute:: abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.written_duration
   :noindex:

.. autoattribute:: abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.written_pitch
   :noindex:

.. autoattribute:: abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.written_pitch_indication_is_at_sounding_pitch
   :noindex:

.. autoattribute:: abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.written_pitch_indication_is_nonsemantic
   :noindex:

Methods
-------

.. automethod:: abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.add_artificial_harmonic
   :noindex:

.. automethod:: abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.select
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.__copy__
   :noindex:

.. automethod:: abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.__eq__
   :noindex:

.. automethod:: abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.__mul__
   :noindex:

.. automethod:: abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.__ne__
   :noindex:

.. automethod:: abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.__repr__
   :noindex:

.. automethod:: abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.__rmul__
   :noindex:

.. automethod:: abjad.tools.notetools.NaturalHarmonic.NaturalHarmonic.NaturalHarmonic.__str__
   :noindex:
